use std::net::{IpAddr, Ipv4Addr, Ipv6Addr};

pub fn extract_ipv4(ip: IpAddr) -> Ipv4Addr {
    match ip {
        IpAddr::V4(i) => i,
        IpAddr::V6(_) => {
            panic!("IPv6 found in IPv4 definition!")
        }
    }
}

pub fn extract_ipv6(ip: IpAddr) -> Ipv6Addr {
    match ip {
        IpAddr::V4(_) => {
            panic!("IPv4 found in IPv6 definition!")
        }
        IpAddr::V6(i) => i,
    }
}

pub fn is_mac_address_valid<D: AsRef<str>>(mac: D) -> bool {
    lazy_regex::regex!("^([a-fA-F0-9]{2}[:-]){5}[a-fA-F0-9]{2}$").is_match(mac.as_ref())
}

#[cfg(test)]
mod tests {
    use crate::utils::net_utils::is_mac_address_valid;

    #[test]
    fn mac_addresses() {
        assert!(is_mac_address_valid("FF:FF:FF:FF:FF:FF"));
        assert!(is_mac_address_valid("02:42:a4:6e:f2:be"));

        assert!(!is_mac_address_valid("tata"));
        assert!(!is_mac_address_valid("FF:FF:FF:FF:FF:FZ"));
        assert!(!is_mac_address_valid("FF:FF:FF:FF:FF:FF:FF"));
    }
}
